@@ -1,3 +1,28 @@
+# Copyright (c) 2018, Adrian Dusa
+# All rights reserved.
+# 
+# Redistribution and use in source and binary forms, with or without
+# modification, in whole or in part, are permitted provided that the
+# following conditions are met:
+#     * Redistributions of source code must retain the above copyright
+#       notice, this list of conditions and the following disclaimer.
+#     * Redistributions in binary form must reproduce the above copyright
+#       notice, this list of conditions and the following disclaimer in the
+#       documentation and/or other materials provided with the distribution.
+#     * The names of its contributors may NOT be used to endorse or promote products
+#       derived from this software without specific prior written permission.
+# 
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
+# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+# DISCLAIMED. IN NO EVENT SHALL ADRIAN DUSA BE LIABLE FOR ANY
+# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
 `pof` <-
 function(setms, outcome, data, relation = "necessity", inf.test = "",
          incl.cut = c(0.75, 0.5), add = NULL, ...) {
@@ -466,11 +491,11 @@ function(setms, outcome, data, relation = "necessity", inf.test = "",
             incl.cov <- matrix(NA, nrow = length.expr, ncol = 4)
         }
         else {
-            fc <- apply(data[, conditions], 2, function(x) any(x < 1 & abs(x - round(x)) >= .Machine$double.eps^0.5))
-            incl.cov <- matrix(NA, nrow=nrow(setms), ncol=4)
+            fc <- apply(data[, conditions, drop = FALSE], 2, function(x) any(x < 1 & abs(x - round(x)) >= .Machine$double.eps^0.5))
+            incl.cov <- matrix(NA, nrow = nrow(setms), ncol = 4)
             length.expr <- nrow(setms)
             mins <- apply(setms, 1, function(e) {
-                apply(data[, conditions, drop=FALSE], 1, function(v) {
+                apply(data[, conditions, drop = FALSE], 1, function(v) {
                     if (any(ox <- e[fc] == 1)) {
                         v[fc][ox] <- 1 - v[fc][ox]
                     }
